@@ -5,11 +5,11 @@ package DBIx::SearchBuilder;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "0.83_05";
+$VERSION = "0.89_02";
 
 =head1 NAME
 
-DBIx::SearchBuilder - Perl extension for easy SQL SELECT Statement generation
+DBIx::SearchBuilder - Encapsulate SQL queries and rows in simple perl objects
 
 =head1 SYNOPSIS
 
@@ -108,15 +108,15 @@ sub _DoSearch {
     # The initial SELECT or SELECT DISTINCT is decided later
 
     $QueryString = $self->_BuildJoins . " ";
+    $QueryString .= $self->_WhereClause . " " . $self->{'table_links'} . " "
+      if ( $self->_isLimited > 0 );
 
     # DISTINCT query only required for multi-table selects
-    if ($QueryString) {
+    if ($self->_isJoined) {
         $self->_DistinctQuery(\$QueryString, $self->{'table'});
     } else {
         $QueryString = "SELECT main.* FROM $QueryString";
     }
-    $QueryString .= $self->_WhereClause . " " . $self->{'table_links'} . " "
-      if ( $self->_isLimited > 0 );
 
     # TODO: GroupBy won't work with postgres.
     # $QueryString .= $self->_GroupByClause. " ";
@@ -202,10 +202,10 @@ sub _DoCount {
     # one place where we build most of the querystring
 
     # DISTINCT query only required for multi-table selects
-    if ($#{$self->{'aliases'}} < 0) {
-        $QueryString = "SELECT count(main.id) FROM ";
-    } else {
+    if ($self->_isJoined) {
         $QueryString = "SELECT count(DISTINCT main.id) FROM ";
+    } else {
+        $QueryString = "SELECT count(main.id) FROM ";
     }
 
     $QueryString .= $self->_BuildJoins . " ";
@@ -306,26 +306,46 @@ sub _BuildJoins {
     my $self = shift;
 
     # if we have a handle specific query builder, let's use that
-    if ($self->_Handle->can('_BuildJoins')) {
-        return ($self->_Handle->_BuildJoins($self));
+    if ( $self->_Handle->can('_BuildJoins') ) {
+        return ( $self->_Handle->_BuildJoins($self) );
     }
 
     #Otherwise, let's do something generic
 
-
     my $join_clause = $self->{'table'} . " main";
 
-
-
     foreach my $join ( keys %{ $self->{'left_joins'} } ) {
-        $join_clause = "( " . $join_clause . $self->{'left_joins'}{$join}{'alias_string'} . " ON  (" .
-          join ( ') AND ( ', values %{ $self->{'left_joins'}{$join}{'criteria'} }) . 
-            "))";
+        $join_clause = "( "
+          . $join_clause
+          . $self->{'left_joins'}{$join}{'alias_string'}
+          . " ON  ("
+          . join ( ') AND ( ',
+                   values %{ $self->{'left_joins'}{$join}{'criteria'} } )
+          . "))";
     }
-    my   $aliases = join ( ", ", @{ $self->{'aliases'} } );
+    my $aliases = join ( ", ", @{ $self->{'aliases'} } );
     $join_clause .= ", $aliases" if ($aliases);
 
-   return ($join_clause);
+    return ($join_clause);
+
+}
+
+# }}}
+# {{{ sub _isJoined
+
+=head2 _isJoined 
+
+Returns true if this Searchbuilder requires joins between tables
+
+=cut
+
+sub _isJoined {
+    my $self = shift;
+    if (keys(%{$self->{'left_joins'}})) {
+        return(1);
+    } else {
+        return(@{$self->{'aliases'}});
+    }
 
 }
 
@@ -766,7 +786,7 @@ sub _GenericRestriction {
 
     # If it's a new value or we're overwriting this sort of restriction,
 
-    if ( $self->_Handle->CaseSensitive ) {
+    if ( $self->_Handle->CaseSensitive && defined $args{'VALUE'} && $args{'VALUE'} ne '' ) {
 
         unless ( $args{'CASESENSITIVE'} ) {
             $QualifiedField = "lower($QualifiedField)";
@@ -911,24 +931,59 @@ ORDER defaults to ASC(ending).  DESC(ending) is also a valid value for OrderBy
 
 sub OrderBy {
     my $self = shift;
-    my %args = ( ALIAS => 'main',
-                 FIELD => undef,
-                 ORDER => 'ASC',
-                 @_ );
-    $self->{'order_by_alias'} = $args{'ALIAS'};
-    $self->{'order_by_field'} = $args{'FIELD'};
-    if ( $args{'ORDER'} =~ /^des/i ) {
-        $self->{'order_by_order'} = "DESC";
-    }
-    else {
-        $self->{'order_by_order'} = "ASC";
-    }
-
-    $self->RedoSearch();
+    my %args = ( @_ );
 
+    $self->OrderByCols( \%args );
 }
 
-# }}}
+=head2 OrderByCols ARRAY
+
+OrderByCols takes an array of paramhashes of the form passed to OrderBy.
+The result set is ordered by the items in the array.
+
+=cut
+
+sub OrderByCols {
+    my $self = shift;
+    my @args = @_;
+    my $row;
+    my $clause;
+
+    foreach $row ( @args ) {
+
+        my %rowhash = ( ALIAS => 'main',
+			FIELD => undef,
+			ORDER => 'ASC',
+			%$row
+		      );
+        if ($rowhash{'ORDER'} =~ /^des/i) {
+	    $rowhash{'ORDER'} = "DESC";
+        }
+        else {
+	    $rowhash{'ORDER'} = "ASC";
+        }
+
+        if ( ($rowhash{'ALIAS'}) and
+	     ($rowhash{'FIELD'}) and
+             ($rowhash{'ORDER'}) ) {
+
+            $clause .= ($clause ? ", " : " ");
+            $clause .= $rowhash{'ALIAS'} . ".";
+            $clause .= $rowhash{'FIELD'} . " ";
+            $clause .= $rowhash{'ORDER'};
+        }
+    }
+
+    if ($clause) {
+	$self->{'order_clause'} = "ORDER BY" . $clause;
+    }
+    else {
+	$self->{'order_clause'} = "";
+    }
+    $self->RedoSearch();
+}
+
+# }}} 
 
 # {{{ sub _OrderClause
 
@@ -941,26 +996,10 @@ returns the ORDER BY clause for the search.
 sub _OrderClause {
     my $self = shift;
 
-    my $clause = "";
-
-    #If we don't have an order defined, set the defaults
-    unless ( defined $self->{'order_by_field'} ) {
-        $self->OrderBy();
+    unless ( defined $self->{'order_clause'} ) {
+	return "";
     }
-
-    if (     ( $self->{'order_by_field'} )
-         and ( $self->{'order_by_alias'} )
-         and ( $self->{'order_by_order'} ) ) {
-
-        $clause = "ORDER BY ";
-        $clause .= $self->{'order_by_alias'} . "."
-          if ( $self->{'order_by_alias'} );
-        $clause .= $self->{'order_by_field'};
-        $clause .= " " . $self->{'order_by_order'}
-          if ( $self->{'order_by_order'} );
-    }
-
-    return ($clause);
+    return ($self->{'order_clause'});
 }
 
 # }}}
@@ -1194,6 +1233,8 @@ Returns the number of records in the set.
 
 =cut
 
+
+
 sub Count {
     my $self = shift;
 
